@@ -6,23 +6,26 @@ from mercadopago.http.http_client import HttpClient
 from mercadopago.resources.advanced_payment import AdvancedPayment
 from mercadopago.resources.card import Card
 from mercadopago.resources.card_token import CardToken
+from mercadopago.resources.chargeback import Chargeback
 from mercadopago.resources.customer import Customer
 from mercadopago.resources.disbursement_refund import DisbursementRefund
 from mercadopago.resources.identification_type import IdentificationType
 from mercadopago.resources.merchant_order import MerchantOrder
 from mercadopago.resources.payment import Payment
 from mercadopago.resources.payment_methods import PaymentMethods
+from mercadopago.resources.plan import Plan
 from mercadopago.resources.preapproval import PreApproval
 from mercadopago.resources.preference import Preference
 from mercadopago.resources.refund import Refund
+from mercadopago.resources.subscription import Subscription
 from mercadopago.resources.user import User
-from mercadopago.resources.chargeback import Chargeback
 
 
 __all__ = (
     'AdvancedPayment',
     'Card',
     'CardToken',
+    'Chargeback',
     'Customer',
     'DisbursementRefund',
     'HttpClient',
@@ -30,10 +33,11 @@ __all__ = (
     'MerchantOrder',
     'Payment',
     'PaymentMethods',
+    'Plan',
     'PreApproval',
     'Preference',
     'Refund',
     'RequestOptions',
+    'Subscription',
     'User',
-    'Chargeback',
 )
